=====
tiepy
=====

.. image:: https://github.com/twguest/tiepy/actions/workflows/testing.yml/badge.svg
   :target: https://github.com/twguest/tiepy/actions/workflows/testing.yml


.. image:: https://img.shields.io/pypi/v/tiepy.svg
        :target: https://pypi.python.org/pypi/tiepy


Solutions to the Transport of Intensity Equation in Python

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://twguest.github.io/tiepy.

Features
--------

* TODO
